BinaryData
==========

.. currentmodule:: oda_api.data_products

.. autoclass:: BinaryData
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BinaryData.decode
      ~BinaryData.encode

   .. rubric:: Methods Documentation

   .. automethod:: decode
   .. automethod:: encode
